USE DbTesting
GO

IF object_id('TestCreateOrderLine')IS NOT Null
    DROP PROCEDURE TestCreateOrderLine
GO

CREATE PROCEDURE TestCreateOrderLine
AS
BEGIN
    EXEC CreateOrderLine @Customer = 'Carlos Santana', @ProductName = 'Plectrum', @Count = 1, @Price = 42
    
    DECLARE @foundProduct  varchar(80)
	DECLARE @foundQuantity int
    DECLARE @foundPrice    int

    SELECT @foundProduct = ProductName,
           @foundQuantity = OrderLine.Count,
           @foundPrice = Price
    FROM Orders 
    INNER JOIN OrderLine ON Orders.ID = OrderLine.OrderID
    WHERE Customer = 'Carlos Santana'

    EXEC SPUnit.dbo.Assert @foundProduct, 'Plectrum'
    EXEC SPUnit.dbo.Assert @foundQuantity, 1
    EXEC SPUnit.dbo.Assert @foundPrice, 42

END
GO

USE DbTesting
GO

IF object_id('Suite')IS NOT Null
    DROP PROCEDURE Suite
GO

CREATE PROCEDURE Suite
    @setup varchar(80) = Null OUTPUT,
    @teardown varchar(80) = Null OUTPUT
AS
BEGIN
    -- This is the only assumption that SPUnit makes about your tests 
    -- that the database will have a Suite procedure and that Procedure 
    -- has two optional OUTPUT parameters anme setup and teardown each varchar(80). 
    -- Here is how to implement the Suite so it will run our tests with their fixture:

    EXEC SPUnit.dbo.AddTest 'DBTesting.dbo.TestCreateOrderLine'

    -- SET @setup = ''
END
GO


USE SPUnit
GO

DECLARE @testCount int
DECLARE @failureCount int
DECLARE @passCount int
EXEC Run 'DBTesting', @testCount OUTPUT, @failureCount OUTPUT

SET @passCount = @testCount - @failureCount

PRINT 'run: ' + CONVERT( varchar(4), @testCount ) +
      ' passed: ' + CONVERT(varchar(4), @passCount ) +
      ' failed: ' + CONVERT( varchar(4), @failureCount )
      
      